@@ -17,10 +17,10 @@ class BayesianOptimization:
         fn: fn_type,
         params: params_type,
         *,
-        gp_params: Dict[str, Any] = None,
+        gp_params: Optional[Dict[str, Any]] = None,
         acquisition: str = "ucb",
-        normalization: Union[str, None] = "cube",
-        normalization_config: Dict[str, Any] = None,
+        normalization: Optional[str] = "cube",
+        normalization_config: Optional[Dict[str, Any]] = None,
         xi: float = 0.01,
         kappa: float = 2.0,
         kappa_decay: float = 1.0,
