@@ -9,14 +9,12 @@ from ..bases import Optimizer, GradientDescentMixin
 class SGD(Optimizer):
     def __init__(self, lr, **kwargs):
         super().__init__(lr)
-        self._momentum = kwargs.get("momentum", 0.)
+        self._momentum = kwargs.get("momentum", 0.0)
         self._nesterov = kwargs.get("nesterov", False)
 
-    def step(self,
-             model: GradientDescentMixin,
-             gradient_dict: Dict[str, np.ndarray]):
+    def step(self, model: GradientDescentMixin, gradient_dict: Dict[str, np.ndarray]):
         for key, value in gradient_dict.items():
-            if self._momentum <= 0.:
+            if self._momentum <= 0.0:
                 gradient = value
             else:
                 velocity = self._caches.setdefault(key, np.zeros_like(value))
